@@ -7,25 +7,38 @@ set_absolute_paths <- function(defs){
               "dict.path",
               "tree.path")
   
-  if(defs$basedir == c("")){
+  if(defs$basedir == ""){
     defs$basedir <- "./"
   }
   
-  defs$basedir <- normalizePath(defs$basedir)
+  defs$dirsep <- ifelse(.Platform$OS.type == "windows", "\\", "/")
+
+  defs$basedir <- gsub("[/|\\]*$", "", normalizePath(defs$basedir))
+
   
   defs$paths <- data.frame(field = character(), 
                            rel   = character(),
                            abs   = character())
   
+ 
+  
   for (i in seq_along(fields)){
     if(!is.null(defs[[fields[i]]]) && defs[[fields[i]]] != ""){
+      rel <- gsub("[/|\\]*$", "", defs[[fields[i]]])
+      if(.Platform$OS.type == "windows"){
+        rel <- gsub("/", "\\", rel, fixed = TRUE)
+      } else {
+        rel <- gsub("\\", "/", rel, fixed = TRUE)
+      }
+      
       defs$paths <- rbind(defs$paths, 
                           data.frame(field = fields[i], 
-                                     rel   = defs[[fields[i]]],
-                                     abs   = paste0(defs$basedir, "/", 
-                                                    defs[[fields[i]]])))
-      defs[[fields[i]]] <- paste0(defs$basedir, "/", defs[[fields[i]]])
+                                     rel   = rel,
+                                     abs   = paste0(defs$basedir, defs$dirsep, 
+                                                    rel)))
+      defs[[fields[i]]] <- defs$paths$abs[nrow(defs$paths)]
+      
     }
   }
   return(defs)
-}
\ No newline at end of file
+}
